/*
    RdfsUpdate: A research tool for RDFS data
    Copyright (C) 2009-2011 Eindhoven University of Technology - www.tue.nl
    Copyright (C) 2009-2011 Wouter Haffmans <wouter@simply-life.net>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/

#ifndef RDFS_RDFSCHAINSTATS_H
#define RDFS_RDFSCHAINSTATS_H

#include "rdfschaincommand.h"
#include "../rdfsbackend.h"
#include "../triple.h"

#include <QSet>
#include <QMap>
#include <QList>
#include <QPair>

namespace Rdfs {

class RdfsUpdate;

typedef QPair<QString, quint64> AtomDegree;

inline bool operator<(const Rdfs::AtomDegree &d1, const Rdfs::AtomDegree &d2) {
    return d1.second < d2.second;
}

struct ChainStatistics {
    quint64 count;
    float avgLength;
    QStringList minChain;
    QStringList maxChain;
};

class RdfsChainStats : public Rdfs::RdfsChainCommand
{
    Q_OBJECT
private:
    QList<AtomDegree> top(QMap<QString, quint64> map, int count = 10);
    void resetStats();

    // Chain statistics
    quint64 m_tripleCount;
    ChainStatistics m_stats;
    // Interesting atoms
    QSet<QString> m_roots, m_leaves;
    QMap<QString, quint64> m_inDegree, m_outDegree, m_totalDegree;

    void countTriple(const Rdfs::Triple &t);
    void incDegree(QMap<QString, quint64> *degreeList, const QString &atom);

protected:
    virtual void foundChain(const QList< QString >& atoms, const QString& predicate);
    virtual void startChain(const Rdfs::Triple& t);
    virtual void skipTriple(const Rdfs::Triple& t);

public:
    RdfsChainStats(RdfsUpdate* parent);
    virtual ~RdfsChainStats();

    virtual bool exec(const QStringList& arguments);
    virtual QString checkArguments(const QStringList& arguments) const;

    virtual bool requireConnection() const { return true; };
    virtual QList< Rdfs::CommandParameter > arguments() const;
    virtual QStringList aliases() const { return QStringList() << "cs"; };
    virtual QString description() const { return tr("Get the statistics of a transitive property, like 'sc' and 'sp' in the current graph."); };
    virtual QString name() const { return "chainstats"; };
};

}

#endif // RDFS_RDFSCHAINSTATS_H
