/*
    RdfsUpdate: A research tool for RDFS data
    Copyright (C) 2009-2011 Eindhoven University of Technology - www.tue.nl
    Copyright (C) 2009-2011 Wouter Haffmans <wouter@simply-life.net>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/

#ifndef RDFS_RDFSCLOSURECHECK_H
#define RDFS_RDFSCLOSURECHECK_H

#include <QStringList>
#include <sys/time.h>

#include "rdfstriplecommand.h"
#include "../rdfssql.h"
#include "../rdfsgraph.h"
#include "../rdfsrules/rdfsrule.h"

namespace Rdfs {

class RdfsClosureCheck : public Rdfs::RdfsTripleCommand {
    Q_OBJECT
private:
    RdfsGraph getGraph(QString predicate, RdfsTable table = RDFS_ORIGINAL);

    QList<RdfsRule *> rdfsRules(RdfsTable table = RDFS_ORIGINAL);
    void loadMap(RdfsRule *r, QString ruleName, QString mapPredicate, RhoDF index, RdfsTable table);
    void rhodfMap(RdfsRule *r);

    timeval timediff(const timeval &a, const timeval &b);

public:
    RdfsClosureCheck(RdfsUpdate* parent);
    virtual QString name() const { return "closurecheck"; };
    virtual QString description() const { return tr("Check if a triple exists in the closure of the graph in a table. Implementation of algorithm by Munoz et al."
                                                    "Note that custom rules are ignored. Use the \"unchase\" command to check if there is an unchase of the triple. If so, it is also in the closure."); };
    virtual QStringList aliases() const { return QStringList() << "cc"; };

    virtual QString checkArguments(const QStringList& arguments) const;
    virtual bool exec(const QStringList& arguments);
    /**
     * Check if a triple is in the closure of the graph in the given table. This
     * method does the actual work, and should be called if the algorithm isn't used
     * directly because of a user command.
     * @param t The triple to check
     * @param table The table containing the graph
     */
    bool checkClosure(Triple t, RdfsTable table);

    virtual ~RdfsClosureCheck();
};
};

#endif // RDFS_RDFSCLOSURECHECK_H
