/*
    RdfsUpdate: A research tool for RDFS data
    Copyright (C) 2009-2011 Eindhoven University of Technology - www.tue.nl
    Copyright (C) 2009-2011 Wouter Haffmans <wouter@simply-life.net>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/

#include "rdfshelp.h"
#include "../rdfsupdate.h"
#include "../rdfslogger.h"

using namespace Rdfs;


RdfsHelp::RdfsHelp(RdfsUpdate* parent)
    : RdfsCommand(parent)
{
}


QList<CommandParameter> RdfsHelp::arguments() const {
    CommandParameter command;
    command.name = tr("command");
    command.examples << tr("help");
    command.help = tr("Command to get extra info about.");
    command.required = false;

    return (QList<CommandParameter>() << command);
}


bool RdfsHelp::exec(const QStringList &arguments) {
    RdfsCommand *cmd;
    if (arguments.count() == 0) {
        Q_FOREACH(cmd, framework()->commands()) {
            RdfsLogger::instance()->log(QString("%1 %2 %3").arg(cmd->name(), 16).arg(cmd->aliases().join(", "), 6).arg(cmd->description()));
        }
        RdfsLogger::instance()->log("\n" + tr("Enter 'help [command]' (e.g. 'help help') to get more specific information about a command."));
        return true;
    }
    else {
        cmd = framework()->command(arguments.at(0));
        if (cmd != 0) {
            framework()->usage(cmd);
            return true;
        }
        else {
            RdfsLogger::instance()->error(tr("Unknown command: %1").arg(arguments.at(0)));
            return false;
        }
    }
}

RdfsHelp::~RdfsHelp() {

}

#include "rdfshelp.moc"
