/*
    RdfsUpdate: A research tool for RDFS data
    Copyright (C) 2009-2011 Eindhoven University of Technology - www.tue.nl
    Copyright (C) 2009-2011 Wouter Haffmans <wouter@simply-life.net>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/

#include "rdfsinsert.h"
#include "../rdfsupdate.h"

using namespace Rdfs;


RdfsInsert::RdfsInsert(RdfsUpdate* parent)
    : RdfsTripleCommand(parent)
{
}

QString RdfsInsert::checkArguments(const QStringList& arguments) const {
    QString baseResult = RdfsTripleCommand::checkArguments(arguments);
    if (baseResult.isEmpty()) {
        // Check that triple does not contain empty items
        RdfsTable table;
        Triple t;
        extractArguments(arguments, &table, &t);

        if (t.subject.isEmpty() || t.predicate.isEmpty() || t.object.isEmpty()) {
            return tr("The triple contains an empty value. This is not supported.");
        }
    }
    return baseResult;
}

bool RdfsInsert::exec(const QStringList& arguments)
{
    RdfsTable table;
    Triple t;
    extractArguments(arguments, &table, &t);

    framework()->store()->insertTriple(t, table);
    return true;
}

RdfsInsert::~RdfsInsert()
{

}

#include "rdfsinsert.moc"

