/*
    RdfsUpdate: A research tool for RDFS data
    Copyright (C) 2009-2011 Eindhoven University of Technology - www.tue.nl
    Copyright (C) 2009-2011 Wouter Haffmans <wouter@simply-life.net>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/

#ifndef RDFS_RDFSKILLCYCLES_H
#define RDFS_RDFSKILLCYCLES_H

#include "../rdfscommand.h"
#include "../rdfsbackend.h"
#include "../triple.h"

#include <QSet>


namespace Rdfs {

class RdfsKillCycles : public Rdfs::RdfsCommand
{
    Q_OBJECT
private:
    enum ChainDirection {
        RDFS_UP = 0,
        RDFS_DOWN = 1,
    };

public:
    virtual bool exec(const QStringList& arguments);
    virtual QList< Rdfs::CommandParameter > arguments() const;
    virtual QString checkArguments(const QStringList& arguments) const;
    virtual bool requireConnection() const { return true; };
    virtual QStringList aliases() const { return QStringList() << "kc"; };
    virtual QString description() const { return tr("Make sure a graph of a given predicate contains no cycles. Cycles will be broken by removing a statement."); };
    virtual QString name() const { return tr("killcycles"); };

    RdfsKillCycles(Rdfs::RdfsUpdate* parent);
    virtual ~RdfsKillCycles();
};

}

#endif // RDFS_RDFSKILLCYCLES_H
