/*
    RdfsUpdate: A research tool for RDFS data
    Copyright (C) 2009-2011 Eindhoven University of Technology - www.tue.nl
    Copyright (C) 2009-2011 Wouter Haffmans <wouter@simply-life.net>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/

#include "rdfssetoption.h"

#include "../rdfsupdate.h"
#include "../rdfslogger.h"

using namespace Rdfs;

bool RdfsSetOption::exec(const QStringList& arguments)
{
    if (!(framework()->store()->setOption(arguments.at(0), arguments.at(1)))) {
        RdfsLogger::instance()->error(tr("An error occured applying the option."));
        return false;
    }
    return true;
}

QString RdfsSetOption::checkArguments(const QStringList& arguments) const
{
    QStringList options = framework()->store()->options();

    if (!options.contains(arguments.at(0))) {
        return tr("Key is not a supported option by the currently connected back-end.");
    }
    return QString();
}

QList< Rdfs::CommandParameter > RdfsSetOption::arguments() const
{
    CommandParameter key;
    key.name = "key";
    key.help = "The key of the option to set (use listoptions to view the supported options)";
    key.examples << "mySetting";
    key.required = true;

    CommandParameter value;
    value.name = "value";
    value.help = "The value to set for the option.";
    value.examples << "myValue";
    value.required = true;

    return QList<CommandParameter>() << key << value;
}

RdfsSetOption::RdfsSetOption(Rdfs::RdfsUpdate* parent): RdfsCommand(parent)
{

}

RdfsSetOption::~RdfsSetOption()
{

}

