/*
    RdfsUpdate: A research tool for RDFS data
    Copyright (C) 2009-2011 Eindhoven University of Technology - www.tue.nl
    Copyright (C) 2009-2011 Wouter Haffmans <wouter@simply-life.net>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/

#include "rdfstruncate.h"

#include "../triple.h"
#include "../rdfsupdate.h"
#include "../rdfssql.h"

using namespace Rdfs;


RdfsTruncate::RdfsTruncate ( RdfsUpdate* parent ) : RdfsCommand ( parent )
{
}

RdfsTruncate::~RdfsTruncate()
{
}


bool RdfsTruncate::exec (const QStringList& arguments)
{
    RdfsTable table = RDFS_ORIGINAL;
    if (arguments.count() > 0) {
        if (arguments.at(0).compare("original", Qt::CaseInsensitive) == 0) {
            table = RDFS_ORIGINAL;
        }
        else if (arguments.at(0).compare("update", Qt::CaseInsensitive) == 0) {
            table = RDFS_UPDATE;
        }
        else if (arguments.at(0).compare("rules", Qt::CaseInsensitive) == 0) {
            table = RDFS_RULE;
        }
    }

    // Remove rules
    if (table == RDFS_RULE) {
        QList<Rule> rules = framework()->store()->rules();
        Q_FOREACH(Rule r, rules) {
            framework()->store()->removeRule(r);
        }
    }

    framework()->store()->truncate(table);
    return true;
}

QString RdfsTruncate::checkArguments (const QStringList& arguments) const
{
    QString argumentsError;
    int base = 0;

    if (arguments.count() > 0) {
        if (arguments.at(0).compare("original", Qt::CaseInsensitive) != 0 &&
            (arguments.at(0).compare("update", Qt::CaseInsensitive) != 0) &&
            (arguments.at(0).compare("rules", Qt::CaseInsensitive) != 0)) {
            argumentsError = tr("Unknown table %1 given.").arg(arguments.at(0));
        }
        ++base;
    }
    return argumentsError;
}

bool RdfsTruncate::requireConnection() const
{
    return true;
}

QList<Rdfs::CommandParameter> RdfsTruncate::arguments() const
{
    CommandParameter table;
    table.name = tr("table");
    table.examples << "original";
    table.examples << "update";
    table.examples << "rules";
    table.help = tr("Table to use for this command.");
    table.required = false;

    return (QList<CommandParameter>() << table);
}

QStringList RdfsTruncate::aliases() const
{
    return (QStringList());
}

QString RdfsTruncate::description() const
{
    return tr("Remove all triples in a table. If \"rules\" is given, remove all rules.");
}

QString RdfsTruncate::name() const
{
    return "truncate";
}

#include "rdfstruncate.moc"
