/*
    RdfsUpdate: A research tool for RDFS data
    Copyright (C) 2009-2011 Eindhoven University of Technology - www.tue.nl
    Copyright (C) 2009-2011 Wouter Haffmans <wouter@simply-life.net>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/

#include "srand.h"

#include <QDateTime>

using namespace Rdfs;

bool Srand::exec(const QStringList& arguments)
{
    bool ok = true;
    uint seed = (arguments.size() >= 1)
              ? arguments.at(0).toUInt(&ok)
              : QDateTime::currentDateTime().toTime_t();
    qsrand(seed);
    return true;
}

QString Srand::checkArguments(const QStringList& arguments) const
{
    bool ok = true;
    uint seed = (arguments.size() >= 1)
              ? arguments.at(0).toUInt(&ok)
              : 0;

    if (!ok) {
        return tr("Seed must be a positive integer.");
    }

    return QString();
}

QList< Rdfs::CommandParameter > Srand::arguments() const
{
    Rdfs::CommandParameter seed;
    seed.name = "seed";
    seed.help = tr("The seed to seed with (unsigned integer). If not given, the current time is used.");
    seed.examples << "1";
    seed.required = false;
    return QList<Rdfs::CommandParameter>() << seed;

}

Srand::Srand(Rdfs::RdfsUpdate* parent): RdfsCommand(parent)
{

}

Srand::~Srand()
{

}

