/*
    RdfsUpdate: A research tool for RDFS data
    Copyright (C) 2009-2011 Eindhoven University of Technology - www.tue.nl
    Copyright (C) 2009-2011 Wouter Haffmans <wouter@simply-life.net>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/

#include "rdfsbdbcursor.h"

#include "rdfsbdb.h"

using namespace Rdfs;

RdfsBdbCursor::RdfsBdbCursor(RdfsBdb* backend, Triple& query, RdfsTable table)
    : RdfsCursor(backend, query, table)
{
    m_cursor = m_inCursor = m_outCursor = m_edgeCursor = NULL;
    m_flags = 0;
    m_eof = true;
    m_bdb = backend; // Save ourselves dynamic casting during runtime
}

RdfsBdbCursor::~RdfsBdbCursor()
{
    close();
}

bool RdfsBdbCursor::eof() const
{
    return m_eof;
}

void RdfsBdbCursor::close()
{
    if (m_cursor != NULL) {
        m_cursor->c_close(m_cursor);
        m_cursor = NULL;
    }
    if (m_inCursor != NULL) {
        m_inCursor->c_close(m_inCursor);
        m_inCursor = NULL;
    }
    if (m_outCursor != NULL) {
        m_outCursor->c_close(m_outCursor);
        m_outCursor = NULL;
    }
    if (m_edgeCursor != NULL) {
        m_edgeCursor->c_close(m_edgeCursor);
        m_edgeCursor = NULL;
    }
    m_open = false;
    m_eof = true;
}

bool RdfsBdbCursor::open()
{
    if (m_cursor != NULL) {
        return false; // Can't reopen cursor - close first
    }
    if (m_bdb->findTripleCursor(queryTriple(), queryTable(), &m_cursor, &m_inCursor, &m_outCursor, &m_edgeCursor, &m_flags) == 0) {
        m_open = true;
        m_eof = false;
        next(); // Load first result
        // Note; if next() has no first result, m_eof is now true. Otherwise m_eof is false.
        return (!m_eof);
    }
    return false;
}

bool RdfsBdbCursor::next()
{
    DBT key, data;
    memset(&key, 0, sizeof(DBT));
    memset(&data, 0, sizeof(DBT));

    int ret = m_cursor->c_get(m_cursor, &key, &data, m_flags);
    if (ret == 0) {
        m_current = m_bdb->dbtToTriple(&data);
        return true;
    }
    else {
        m_current = Triple();
        m_eof = true;
        return false;
    }
}

Rdfs::Triple RdfsBdbCursor::current() const
{
    return m_current;
}
