/*
    RdfsUpdate: A research tool for RDFS data
    Copyright (C) 2009-2011 Eindhoven University of Technology - www.tue.nl
    Copyright (C) 2009-2011 Wouter Haffmans <wouter@simply-life.net>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/

#include "rdfslistcursor.h"
#include "rdfsbdb.h"

Rdfs::RdfsListCursor::RdfsListCursor(Rdfs::RdfsBackend* backend, const Rdfs::Triple& query, Rdfs::RdfsTable table)
    : RdfsCursor(backend, query, table)
{
    m_list = backend->findTriples(query, table);
    m_cursor = m_list.constEnd();
}

Rdfs::RdfsListCursor::~RdfsListCursor()
{
    close();
}

bool Rdfs::RdfsListCursor::open()
{
    if (!m_open && m_list.size() > 0) {
        m_cursor = m_list.constBegin();
        return true;
    }
    return false;
}

bool Rdfs::RdfsListCursor::next()
{
    if (!eof()) {
        ++m_cursor;
        return true;
    }
    return false;
}

Rdfs::Triple Rdfs::RdfsListCursor::current() const
{
    if (!eof()) {
        return *m_cursor;
    }
    else {
        return Triple();
    }
}

bool Rdfs::RdfsListCursor::eof() const
{
    return (m_cursor == m_list.constEnd());
}

void Rdfs::RdfsListCursor::close()
{
    m_cursor = m_list.constEnd();
}

