/*
    RdfsUpdate: A research tool for RDFS data
    Copyright (C) 2009-2011 Eindhoven University of Technology - www.tue.nl
    Copyright (C) 2009-2011 Wouter Haffmans <wouter@simply-life.net>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/

#include <QString>
#include <QIODevice>
#include <QFile>
#include <stdio.h>

#include "rdfslogger.h"

using namespace Rdfs;

// Initialize statics
RdfsLogger *RdfsLogger::m_instance = 0;
QMutex RdfsLogger::m_mutex(QMutex::NonRecursive);

RdfsLogger::RdfsLogger(QObject* parent)
    : QObject(parent) {
    m_in = new QFile();
    m_in->open(stdin, QIODevice::ReadOnly);
    m_out = new QFile();
    m_out->open(stdout, QIODevice::WriteOnly);
    m_err = new QFile();
    m_err->open(stderr, QIODevice::WriteOnly);
}

RdfsLogger* RdfsLogger::instance() {
    if (m_instance == 0) {
        m_mutex.lock();
        if (m_instance == 0) {
            m_instance = new RdfsLogger();
        }
        m_mutex.unlock();
    }
    return m_instance;
}

void RdfsLogger::log(const QString &message) {
    writeMessage(message, m_out);
    m_out->flush();
}

void RdfsLogger::reprint(const QString &message) {
    // Only reprint if the input or output are not both on a terminal (sequential device)
    if (!m_out->isSequential() || !m_in->isSequential()) {
        writeMessage(message, m_out);
        m_out->flush();
    }
}

void RdfsLogger::error(const QString &message) {
    writeMessage(message, m_err);
    m_err->flush();
}


void RdfsLogger::writeMessage(const QString& message, QIODevice* target) {
    target->write(message.toUtf8());
    if (!message.endsWith("\n")) {
        target->write("\n");
    }
}

void RdfsLogger::prompt(const QString& prompt) {
    m_out->write(prompt.toUtf8());
    m_out->flush();
}



RdfsLogger::~RdfsLogger() {
    m_in->close();
    m_out->flush();
    m_out->close();
    m_err->flush();
    m_err->close();
}

#include "rdfslogger.moc"
