/*
    RdfsUpdate: A research tool for RDFS data
    Copyright (C) 2009-2011 Eindhoven University of Technology - www.tue.nl
    Copyright (C) 2009-2011 Wouter Haffmans <wouter@simply-life.net>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/

#ifndef RDFSLOGGER_H
#define RDFSLOGGER_H

#include <QMutex>
#include <QObject>

class QFile;
class QIODevice;

namespace Rdfs {

class RdfsLogger : public QObject {
    Q_OBJECT
private:
    static RdfsLogger *m_instance;
    static QMutex m_mutex;

    /** Stdin file handle */
    QFile *m_in;
    /** Stdout file handle */
    QFile *m_out;
    /** Stderr file handle */
    QFile *m_err;

    inline void writeMessage(const QString& message, QIODevice* target);

protected:
    RdfsLogger(QObject *parent = 0);

public:
    static RdfsLogger *instance();

    virtual ~RdfsLogger();

public slots:
    void log(const QString& message);
    /**
     * Log a message if input or output is non-sequential
     */
    void reprint(const QString& message);
    #ifndef NDEBUG
    inline void debug(const QString &message) { qDebug("%s", message.toUtf8().constData()); };
    #else
    // Do nothing, this optimizes well :)
    inline void debug(const QString &message) {};
    #endif
    void error(const QString &message);
    void prompt(const QString &prompt);
};
};
#endif // RDFSLOGGER_H
