/*
    RdfsUpdate: A research tool for RDFS data
    Copyright (C) 2009-2011 Eindhoven University of Technology - www.tue.nl
    Copyright (C) 2009-2011 Wouter Haffmans <wouter@simply-life.net>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/

#ifndef RDFS_RDFSRULE_H
#define RDFS_RDFSRULE_H

#include <QMap>
#include <QString>
#include "../triple.h"
#include "../rdfsupdate.h"

namespace Rdfs {

class RdfsBackend;

enum RhoDF {
    RDFS_SP = 1,
    RDFS_SC = 2,
    RDFS_TYPE = 3,
    RDFS_DOM = 4,
    RDFS_RANGE = 5
};

class RdfsRule
{
    private:
        QMap<RhoDF, QString> m_termMap;

    public:
        RdfsRule();
        virtual ~RdfsRule();

        virtual bool check(Triple t, RdfsTable table, RdfsBackend *store) = 0;

        virtual void setMap(RhoDF original, QString term);
        virtual void removeMap(RhoDF original);
        virtual bool containsMap(RhoDF original);
        virtual QString map(RhoDF original);
};

}

#endif // RDFS_RDFSRULE_H
