/*
    RdfsUpdate: A research tool for RDFS data
    Copyright (C) 2009-2011 Eindhoven University of Technology - www.tue.nl
    Copyright (C) 2009-2011 Wouter Haffmans <wouter@simply-life.net>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/

#include "subclassrule.h"

#include <QSet>
#include <QStringList>

#include "../rdfsbackend.h"

using namespace Rdfs;

SubclassRule::SubclassRule()
 : TransitiveRule()
{

}

bool SubclassRule::check(Rdfs::Triple t, Rdfs::RdfsTable table, RdfsBackend *store)
{
    if (!containsMap(RDFS_SC) || t.predicate != map(RDFS_SC)) {
        return false;
    }

    // Reflexivity first; if A == B, then this will also catch the transitivity.
    // If this isn't found, then the transitivity will also find nothing
    // Step 3b of the algorithm
    if (t.subject == t.object) {
        // Gather triples to check
        QSet<Triple> ts;
        // check for (A sc X) or (X sc A)
        Triple t1;
        t1.subject = t.subject;
        t1.predicate = t.predicate;
        t1.object = QString();

        Triple t2;
        t2.subject = QString();
        t2.predicate = t.predicate;
        t2.object = t.subject;
        ts << t1 << t2;

        // And add in dom/range/type-like terms
        QStringList predicateList;
        if (containsMap(RDFS_DOM)) {
            predicateList << map(RDFS_DOM);
        }
        if (containsMap(RDFS_RANGE)) {
            predicateList << map(RDFS_RANGE);
        }
        if (containsMap(RDFS_TYPE)) {
            predicateList << map(RDFS_TYPE);
        }

        Q_FOREACH(QString term, predicateList) {
            Triple tt;
            tt.subject = QString();
            tt.predicate = term;
            tt.object = t.subject;

            ts << tt;
        }

        // Check triples in triple set
        Q_FOREACH(Triple tt, ts) {
            if (store->checkTriple(tt, table) > 0) {
                return true;
            }
        }

        // No match found; return false
        return false;
    }

    // Check transitivity
    return checkTransitive(t, table, store);
}

Rdfs::SubclassRule::~SubclassRule()
{

}
