/*
    RdfsUpdate: A research tool for RDFS data
    Copyright (C) 2009-2011 Eindhoven University of Technology - www.tue.nl
    Copyright (C) 2009-2011 Wouter Haffmans <wouter@simply-life.net>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/

#ifndef RDFS_TRANSITIVERULE_H
#define RDFS_TRANSITIVERULE_H

#include "rdfsrule.h"


namespace Rdfs {

/**
 * Base class which contains implementation of a transitive check. This can check
 * for transitive properties (such as sp, sc) in a graph.
 *
 * Used for steps 2a, 3a of the algorithm (sp, sc transitivity) by
 * SubpropertyRule and SubclassRule
 */
class TransitiveRule : public Rdfs::RdfsRule
{
protected:
    bool checkTransitive(Triple t, RdfsTable table, RdfsBackend *store);

public:
    TransitiveRule();
    virtual ~TransitiveRule();
};

}

#endif // RDFS_TRANSITIVERULE_H
