/*
    RdfsUpdate: A research tool for RDFS data
    Copyright (C) 2009-2011 Eindhoven University of Technology - www.tue.nl
    Copyright (C) 2009-2011 Wouter Haffmans <wouter@simply-life.net>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/

#ifndef RDFS_RDFSTRIPLETCURSOR_H
#define RDFS_RDFSTRIPLETCURSOR_H

#include "rdfscursor.h"

#include <QString>
#include <QList>
#include <QMap>
#include <QStringList>

#include "rdfstripletbackend.h"

namespace Rdfs {

class RdfsTripleTBackend;

class RdfsTripleTCursor : public Rdfs::RdfsCursor
{
private:
    RdfsTripleTBackend *m_ttbackend;

    /**
     * The order of primary/secondary/tertiary, determined by primary.
     *
     * If RDFS_SUBJECT: Subject/Object/Predicate (SOP) order
     * If RDFS_PREDICATE: Predicate/Subject/Object (PSO) order
     * If RDFS_OBJECT: Object/Subject/Predicate (OSP) order
     *
     * Order of preference: SOP, OSP, PSO
     */
    RdfsRole m_order;

    // The list of primary atoms to iterate over
    QStringList m_primaryList;
    QStringList::const_iterator m_primary;

    // Iterators over secondaries/tertiaries
    QMap<QString, QList<TertiaryAtom> > m_payload;
    QMap<QString, QList<TertiaryAtom> >::const_iterator m_secondary;

    QList<TertiaryAtom> m_tertiaryList;
    QList<TertiaryAtom>::const_iterator m_tertiary;

    RdfsCursor *m_btreeCursor;

    Triple m_orderedQuery;

    /**
     * Move on to the next primary.
     *
     * @param init Whether the cursor is being initialized or not.
     */
    void nextPrimary(bool init = false);

    /**
     * Move on to the next secondary.
     *
     * @param init Whether the cursor is being initialized or not.
     */
    void nextSecondary(bool init = false);

    /**
     * Move on to the next secondary.
     *
     * @param init Whether the cursor is being initialized or not.
     */
    void nextTertiary(bool init = false);

public:
    virtual bool eof() const;
    virtual void close();
    virtual bool open();
    virtual bool next();
    virtual Rdfs::Triple current() const;
    RdfsTripleTCursor(Rdfs::RdfsTripleTBackend* backend, const Rdfs::Triple& query, Rdfs::RdfsTable table = RDFS_ORIGINAL);
    virtual ~RdfsTripleTCursor();
};

}

#endif // RDFS_RDFSTRIPLETCURSOR_H
